package com.ruoyi.project.production.service;

import java.util.List;
import com.ruoyi.project.production.domain.TMonthlyQualityReportS4501;

/**
 * 质量月报S4501Service接口
 * 
 * @author ruoyi
 * @date 2023-10-27
 */
public interface ITMonthlyQualityReportS4501Service 
{
    /**
     * 查询质量月报S4501
     * 
     * @param id 质量月报S4501ID
     * @return 质量月报S4501
     */
    public TMonthlyQualityReportS4501 selectTMonthlyQualityReportS4501ById(Long id);

    /**
     * 查询质量月报S4501列表
     * 
     * @param tMonthlyQualityReportS4501 质量月报S4501
     * @return 质量月报S4501集合
     */
    public List<TMonthlyQualityReportS4501> selectTMonthlyQualityReportS4501List(TMonthlyQualityReportS4501 tMonthlyQualityReportS4501);

    /**
     * 新增质量月报S4501
     * 
     * @param tMonthlyQualityReportS4501 质量月报S4501
     * @return 结果
     */
    public int insertTMonthlyQualityReportS4501(TMonthlyQualityReportS4501 tMonthlyQualityReportS4501);

    /**
     * 修改质量月报S4501
     * 
     * @param tMonthlyQualityReportS4501 质量月报S4501
     * @return 结果
     */
    public int updateTMonthlyQualityReportS4501(TMonthlyQualityReportS4501 tMonthlyQualityReportS4501);

    /**
     * 批量删除质量月报S4501
     * 
     * @param ids 需要删除的质量月报S4501ID
     * @return 结果
     */
    public int deleteTMonthlyQualityReportS4501ByIds(Long[] ids);

    /**
     * 删除质量月报S4501信息
     * 
     * @param id 质量月报S4501ID
     * @return 结果
     */
    public int deleteTMonthlyQualityReportS4501ById(Long id);
}
